        function getR(rrw){
           cx=0;
       cx+=1;
       if(rrw==cx){return 2;}
       cx+=1;
       if(rrw==cx){return 9;}
       cx+=1;
       if(rrw==cx){return 10;}
       cx+=1;
       if(rrw==cx){return 11;}
       cx+=1;
       if(rrw==cx){return 12;}
       cx+=1;
       if(rrw==cx){return 13;}
       cx+=1;
       if(rrw==cx){return 14;}
       cx+=1;
       if(rrw==cx){return 15;}
       cx+=1;
       if(rrw==cx){return 16;}
return -1;}
